% Joint Kernel learning via semi-infinite linear programming in binary case
% Coded by Jianhui Chen (jianhui.chen@asu.edu, Arizona State University)

%                Input Parameters
% "G_Ker" : the cell containing centered kernel matrix (trace value = 1) 
% "a" : the indicator vector
% "epislon" : the tolerance parameter


%               Output parameters
% "theta0" : the coefficients of kernel matrices
% "lambda" : regularization parameter
% "time" : computation time in seconds



function  [ theta0 lambda  time ] = SILP_binary_joint( G_Ker, a, epislon )

time0 = cputime;

n = length(a);
len = length(G_Ker) + 1;
G{1} = diag( ones(1,n)/n ) ;
G(2 : len) =G_Ker; 

zeta = 10^300; theta = ones(1, len) / len;

f = [ ]; A = [ ]; b = [ ] ; B = [ ]; c = [ ]; l = [ ] ; u = [ ];
[ f A b B c l u ] = lp_con( len );

%alpha_array = [ ];

for t = 1 : 1000
    
     %t0 = cputime; 
     [ alpha val ] = compute_alpha_ls_joint(G, theta, a);
     %cputime - t0
     
     if ( val > zeta ) |  ( abs(1 - val / zeta) <= epislon )
         break;
     else
         %t0 = cputime
         [ theta, zeta, f, A, b, B, c, l, u ] = compute_theta_lpprog_joint( G, alpha, a, f, A, b, B, c, l, u );
         %cputime - t0
       %  alpha_array = [ alpha_array alpha ];
     end
    
%      [ theta1, zeta1 ] = compute_theta( G, alpha_array, lambda, a );
%      zeta1 
%      zeta
%      theta1'
%      theta'
%       val
%       zeta
end
lambda = theta(1);
theta0 = theta(2:end);
    

time = cputime - time0;
